@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Type, Union, cast
+from typing import TYPE_CHECKING, Dict, List, Optional, Set, Type, Union, cast
 
 from pydantic import validate_arguments
 from pydantic.fields import FieldInfo
@@ -6,7 +6,7 @@ from starlette.middleware import Middleware as StarletteMiddleware
 from starlette.middleware.cors import CORSMiddleware
 from starlette.middleware.trustedhost import TrustedHostMiddleware
 
-from starlite.asgi import StarliteASGIRouter
+from starlite.asgi import PathParamPlaceholder, RouteMapNode, StarliteASGIRouter
 from starlite.config import (
     CacheConfig,
     CompressionConfig,
@@ -20,8 +20,9 @@ from starlite.datastructures import Cookie, ResponseHeader, State
 from starlite.exceptions import ImproperlyConfiguredException
 from starlite.handlers.asgi import ASGIRouteHandler, asgi
 from starlite.handlers.http import HTTPRouteHandler
-from starlite.middleware import CSRFMiddleware, ExceptionHandlerMiddleware
 from starlite.middleware.compression.base import CompressionMiddleware
+from starlite.middleware.csrf import CSRFMiddleware
+from starlite.middleware.exceptions import ExceptionHandlerMiddleware
 from starlite.plugins.base import PluginProtocol
 from starlite.provide import Provide
 from starlite.response import Response
@@ -45,12 +46,21 @@ if TYPE_CHECKING:
     from pydantic_openapi_schema.v3_1_0.open_api import OpenAPI
     from starlette.types import ASGIApp, Receive, Scope, Send
 
+    from starlite.asgi import ComponentsSet, PathParamPlaceholderType
     from starlite.handlers.base import BaseRouteHandler
     from starlite.handlers.websocket import WebsocketRouteHandler
+    from starlite.routes.base import PathParameterDefinition
 
 DEFAULT_OPENAPI_CONFIG = OpenAPIConfig(title="Starlite API", version="1.0.0")
-"""OpenAPI config utilised if not explicitly declared to [Starlite][starlite.app.Starlite] instance constructor."""
+"""
+    The default OpenAPI config used if not configuration is explicitly passed
+    to the [Starlite][starlite.app.Starlite] instance constructor.
+"""
 DEFAULT_CACHE_CONFIG = CacheConfig()
+"""
+    The default cache config used if not configuration is explicitly passed
+    to the [Starlite][starlite.app.Starlite] instance constructor.
+"""
 
 
 class Starlite(Router):
@@ -103,8 +113,7 @@ class Starlite(Router):
         template_config: Optional[TemplateConfig] = None,
         tags: Optional[List[str]] = None,
     ):
-        """
-        The Starlite application.
+        """The Starlite application.
 
         `Starlite` is the root level of the app - it has the base path of "/" and all root level
         Controllers, Routers and Route Handlers should be registered on it.
@@ -112,19 +121,20 @@ class Starlite(Router):
         It inherits from the [Router][starlite.router.Router] class.
 
         Args:
-            after_request: A sync or async function executed before a [Request][starlite.connection.Request] is passed
-                to any route handler. If this function returns a value, the request will not reach the route handler,
-                and instead this value will be used.
+            after_request: A sync or async function executed after the route handler function returned and the response
+                object has been resolved. Receives the response object which may be either an instance of
+                [`Response`][starlite.response.Response] or `starlette.Response`.
             after_response: A sync or async function called after the response has been awaited. It receives the
                 [Request][starlite.connection.Request] object and should not return any values.
-            allowed_hosts: A list of allowed hosts - enables `AllowedHostsMiddleware`.
+            allowed_hosts: A list of allowed hosts - enables the builtin allowed hosts middleware.
             before_request: A sync or async function called immediately before calling the route handler. Receives
                 the `starlite.connection.Request` instance and any non-`None` return value is used for the response,
                 bypassing the route handler.
             cache_config: Configures caching behavior of the application.
-            compression_config: Configures compression behaviour of the application.
-            cors_config: If set this enables the `starlette.middleware.cores.CORSMiddleware`.
-            csrf_config: If set this enables the CSRF middleware.
+            compression_config: Configures compression behaviour of the application, this enabled a builtin or user
+                defined Compression middleware.
+            cors_config: If set this enables the builtin CORS middleware.
+            csrf_config: If set this enables the builtin CSRF middleware.
             debug: If `True`, app errors rendered as HTML with a stack trace.
             dependencies: A string/[Provider][starlite.provide.Provide] dictionary that maps dependency providers.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
@@ -158,7 +168,7 @@ class Starlite(Router):
         self.compression_config = compression_config
         self.plain_routes: Set[str] = set()
         self.plugins = plugins or []
-        self.route_map: Dict[str, Any] = {}
+        self.route_map: RouteMapNode = {}
         self.routes: List[BaseRoute] = []
         self.state = State()
 
@@ -192,9 +202,10 @@ class Starlite(Router):
         self.template_engine = create_template_engine(template_config)
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """
-        The application entry point.
-        Lifespan events (startup / shutdown) are sent to the lifespan handler, otherwise the ASGI handler is used
+        """The application entry point.
+
+        Lifespan events (startup / shutdown) are sent to the lifespan
+        handler, otherwise the ASGI handler is used
         """
         scope["app"] = self
         if scope["type"] == "lifespan":
@@ -204,9 +215,8 @@ class Starlite(Router):
         await self.asgi_handler(scope, receive, send)
 
     def register(self, value: ControllerRouterHandler) -> None:  # type: ignore[override]
-        """
-
-        Registers a route handler on the app. This method can be used to dynamically add endpoints to an application.
+        """Registers a route handler on the app. This method can be used to
+        dynamically add endpoints to an application.
 
         Args:
             value: an instance of [Router][starlite.router.Router], a subclasses of
@@ -236,10 +246,11 @@ class Starlite(Router):
         self._construct_route_map()
 
     def _create_asgi_handler(self) -> "ASGIApp":
-        """
-        Creates an ASGIApp that wraps the ASGI router inside an exception handler.
+        """Creates an ASGIApp that wraps the ASGI router inside an exception
+        handler.
 
-        If CORS or TrustedHost configs are provided to the constructor, they will wrap the router as well.
+        If CORS or TrustedHost configs are provided to the constructor,
+        they will wrap the router as well.
         """
         asgi_handler: "ASGIApp" = self.asgi_router
         if self.compression_config:
@@ -255,33 +266,38 @@ class Starlite(Router):
     def _wrap_in_exception_handler(
         self, app: "ASGIApp", exception_handlers: Dict[Union[int, Type[Exception]], ExceptionHandler]
     ) -> "ASGIApp":
-        """
-        Wraps the given ASGIApp in an instance of ExceptionHandlerMiddleware
-        """
+        """Wraps the given ASGIApp in an instance of
+        ExceptionHandlerMiddleware."""
 
         return ExceptionHandlerMiddleware(app=app, exception_handlers=exception_handlers, debug=self.debug)
 
-    def _add_node_to_route_map(self, route: BaseRoute) -> Dict[str, Any]:
-        """
-        Adds a new route path (e.g. '/foo/bar/{param:int}') into the route_map tree.
+    def _add_node_to_route_map(self, route: BaseRoute) -> RouteMapNode:
+        """Adds a new route path (e.g. '/foo/bar/{param:int}') into the
+        route_map tree.
 
-        Inserts non-parameter paths ('plain routes') off the tree's root node.
-        For paths containing parameters, splits the path on '/' and nests each path
-        segment under the previous segment's node (see prefix tree / trie).
+        Inserts non-parameter paths ('plain routes') off the tree's root
+        node. For paths containing parameters, splits the path on '/'
+        and nests each path segment under the previous segment's node
+        (see prefix tree / trie).
         """
         current_node = self.route_map
         path = route.path
         if route.path_parameters or path in self._static_paths:
-            for param_definition in route.path_parameters:
-                path = path.replace(param_definition["full"], "")
-            path = path.replace("{}", "*")
-            components = ["/", *[component for component in path.split("/") if component]]
+            components = cast(
+                "List[Union[str, PathParamPlaceholderType, PathParameterDefinition]]", ["/", *route.path_components]
+            )
             for component in components:
-                components_set = cast("Set[str]", current_node["_components"])
+                components_set = cast("ComponentsSet", current_node["_components"])
+
+                if isinstance(component, dict):
+                    # Represent path parameters using a special value
+                    component = PathParamPlaceholder
+
                 components_set.add(component)
+
                 if component not in current_node:
                     current_node[component] = {"_components": set()}
-                current_node = cast("Dict[str, Any]", current_node[component])
+                current_node = cast("RouteMapNode", current_node[component])
                 if "_static_path" in current_node:
                     raise ImproperlyConfiguredException("Cannot have configured routes below a static path")
         else:
@@ -292,10 +308,9 @@ class Starlite(Router):
         self._configure_route_map_node(route, current_node)
         return current_node
 
-    def _configure_route_map_node(self, route: BaseRoute, node: Dict[str, Any]) -> None:
-        """
-        Set required attributes and route handlers on route_map tree node.
-        """
+    def _configure_route_map_node(self, route: BaseRoute, node: RouteMapNode) -> None:
+        """Set required attributes and route handlers on route_map tree
+        node."""
         if "_path_parameters" not in node:
             node["_path_parameters"] = route.path_parameters
         if "_asgi_handlers" not in node:
@@ -319,8 +334,9 @@ class Starlite(Router):
             node["_is_asgi"] = True
 
     def _construct_route_map(self) -> None:
-        """
-        Create a map of the app's routes. This map is used in the asgi router to route requests.
+        """Create a map of the app's routes.
+
+        This map is used in the asgi router to route requests.
         """
         if "_components" not in self.route_map:
             self.route_map["_components"] = set()
@@ -336,7 +352,8 @@ class Starlite(Router):
         route: Union[HTTPRoute, WebSocketRoute, ASGIRoute],
         route_handler: Union[HTTPRouteHandler, "WebsocketRouteHandler", ASGIRouteHandler],
     ) -> "ASGIApp":
-        """Constructs a middleware stack that serves as the point of entry for each route"""
+        """Constructs a middleware stack that serves as the point of entry for
+        each route."""
 
         # we wrap the route.handle method in the ExceptionHandlerMiddleware
         asgi_handler = self._wrap_in_exception_handler(
@@ -345,7 +362,8 @@ class Starlite(Router):
 
         for middleware in route_handler.resolve_middleware():
             if isinstance(middleware, StarletteMiddleware):
-                asgi_handler = middleware.cls(app=asgi_handler, **middleware.options)
+                handler, kwargs = middleware
+                asgi_handler = handler(app=asgi_handler, **kwargs)
             else:
                 asgi_handler = middleware(app=asgi_handler)
 
@@ -355,9 +373,8 @@ class Starlite(Router):
         )
 
     def _create_handler_signature_model(self, route_handler: "BaseRouteHandler") -> None:
-        """
-        Creates function signature models for all route handler functions and provider dependencies
-        """
+        """Creates function signature models for all route handler functions
+        and provider dependencies."""
         if not route_handler.signature_model:
             route_handler.signature_model = SignatureModelFactory(
                 fn=cast("AnyCallable", route_handler.fn),
