@@ -9,17 +9,15 @@ if TYPE_CHECKING:
 
 
 class SimpleCacheBackend(CacheBackendProtocol):
-    """
-    This class offers a cache backend that stores values in a dict.
+    """This class offers a cache backend that stores values in a `dict`.
 
-    In a production system you probably should use Redis or MemCached instead.
+    In a production system you probably should use Redis or MemCached
+    instead.
     """
 
     @dataclass()
     class CacheObject:
-        """
-        A container class
-        """
+        """A container class."""
 
         value: Any
         expiration: datetime
@@ -28,8 +26,13 @@ class SimpleCacheBackend(CacheBackendProtocol):
         self._store: Dict[str, Any] = {}
 
     def get(self, key: str) -> Any:
-        """
-        Retrieve a value for a given key
+        """Retrieve value from cache corresponding to the given key.
+
+        Args:
+            key (str): name of cached value.
+
+        Returns:
+            Cached value, or `None`.
         """
         cache_obj = cast("Optional[SimpleCacheBackend.CacheObject]", self._store.get(key))
         if cache_obj:
@@ -39,15 +42,22 @@ class SimpleCacheBackend(CacheBackendProtocol):
         return None
 
     def set(self, key: str, value: Any, expiration: int) -> None:
-        """
-        Set a value for a given key
+        """Set a value in cache for a given key with a given expiration in
+        seconds.
+
+        Args:
+            key (str): key to cache `value` under.
+            value (str): the value to be cached.
+            expiration (int): expiration of cached value in seconds.
         """
         self._store[key] = SimpleCacheBackend.CacheObject(
             value=value, expiration=datetime.now() + timedelta(seconds=expiration)
         )
 
     def delete(self, key: str) -> None:
-        """
-        Remove a value for a given key
+        """Remove a value from the cache for a given key.
+
+        Args:
+            key (str): key to be deleted from the cache.
         """
         self._store.pop(key, None)
