@@ -42,11 +42,8 @@ class BaseRouteHandler(Generic[T]):
 
     __slots__ = (
         "_resolved_dependencies",
-        "_resolved_dependency_name_set",
-        "_resolved_exception_handlers",
         "_resolved_guards",
         "_resolved_layered_parameters",
-        "_resolved_middleware",
         "dependencies",
         "exception_handlers",
         "fn",
@@ -83,31 +80,19 @@ class BaseRouteHandler(Generic[T]):
         self.owner: Optional[Union["Controller", "Router"]] = None
         self.signature_model: Optional[Type["SignatureModel"]] = None
         self._resolved_dependencies: Union[Dict[str, Provide], EmptyType] = Empty
-        self._resolved_dependency_name_set: Union[Set[str], EmptyType] = Empty
-        self._resolved_exception_handlers: Union[Dict[Union[int, Type[Exception]], ExceptionHandler], EmptyType] = Empty
         self._resolved_guards: Union[List[Guard], EmptyType] = Empty
-        self._resolved_middleware: Union[List[Middleware], EmptyType] = Empty
         self._resolved_layered_parameters: Union[Dict[str, "ModelField"], EmptyType] = Empty
 
     @property
     def dependency_name_set(self) -> Set[str]:
-        """
-        The set of all dependency names provided in the handler's ownership layers.
-
-        Intended as a fast to compute set of the names of dependencies provided to the handler, and
-        available at the time that the handler's signature model is generated. Full resolution of
-        dependencies requires that the signature model is already generated and is performed in
-        ``BaseRouteHandler.resolve_dependencies()``.
-        """
-        if self._resolved_dependency_name_set is Empty:
-            layered_dependencies = (layer.dependencies or {} for layer in self.ownership_layers)
-            self._resolved_dependency_name_set = {name for layer in layered_dependencies for name in layer.keys()}
-        return cast("Set[str]", self._resolved_dependency_name_set)
+        """The set of all dependency names provided in the handler's ownership
+        layers."""
+        layered_dependencies = (layer.dependencies or {} for layer in self.ownership_layers)
+        return {name for layer in layered_dependencies for name in layer.keys()}
 
     @property
     def ownership_layers(self) -> List[Union[T, "Controller", "Router"]]:
-        """
-        Returns the handler layers from the app down to the route handler
+        """Returns the handler layers from the app down to the route handler.
 
         app -> ... -> route handler
         """
@@ -121,7 +106,8 @@ class BaseRouteHandler(Generic[T]):
         return list(reversed(layers))
 
     def resolve_layered_parameters(self) -> Dict[str, "ModelField"]:
-        """Returns all parameters declared above the handler, transforming them into pydantic ModelField instances"""
+        """Returns all parameters declared above the handler, transforming them
+        into pydantic ModelField instances."""
         if self._resolved_layered_parameters is Empty:
             self._resolved_layered_parameters = {}
             parameters: Dict[str, FieldInfo] = {}
@@ -146,7 +132,8 @@ class BaseRouteHandler(Generic[T]):
         return cast("Dict[str, ModelField]", self._resolved_layered_parameters)
 
     def resolve_guards(self) -> List[Guard]:
-        """Returns all guards in the handlers scope, starting from highest to current layer"""
+        """Returns all guards in the handlers scope, starting from highest to
+        current layer."""
         if self._resolved_guards is Empty:
             self._resolved_guards = []
             for layer in self.ownership_layers:
@@ -154,9 +141,8 @@ class BaseRouteHandler(Generic[T]):
         return cast("List[Guard]", self._resolved_guards)
 
     def resolve_dependencies(self) -> Dict[str, Provide]:
-        """
-        Returns all dependencies correlating to handler function's kwargs that exist in the handler's scope
-        """
+        """Returns all dependencies correlating to handler function's kwargs
+        that exist in the handler's scope."""
         if not self.signature_model:
             raise RuntimeError("resolve_dependencies cannot be called before a signature model has been generated")
         if self._resolved_dependencies is Empty:
@@ -170,34 +156,30 @@ class BaseRouteHandler(Generic[T]):
         return cast("Dict[str, Provide]", self._resolved_dependencies)
 
     def resolve_middleware(self) -> List["Middleware"]:
-        """
-        Builds the middleware stack for the RouteHandler and returns it.
+        """Builds the middleware stack for the RouteHandler and returns it.
 
-        The middlewares are added from top to bottom (app -> router -> controller -> route handler) and then reversed.
+        The middlewares are added from top to bottom (app -> router ->
+        controller -> route handler) and then reversed.
         """
-        if self._resolved_middleware is Empty:
-            self._resolved_middleware = []
-            for layer in self.ownership_layers:
-                self._resolved_middleware.extend(layer.middleware or [])
-            self._resolved_middleware = list(reversed(self._resolved_middleware))
-        return cast("List[Middleware]", self._resolved_middleware)
+        resolved_middleware = []
+        for layer in self.ownership_layers:
+            resolved_middleware.extend(layer.middleware or [])
+        return list(reversed(resolved_middleware))
 
     def resolve_exception_handlers(self) -> Dict[Union[int, Type[Exception]], ExceptionHandler]:
-        """
-        Resolves the exception_handlers by starting from the route handler and moving up.
+        """Resolves the exception_handlers by starting from the route handler
+        and moving up.
 
         This method is memoized so the computation occurs only once.
         """
-        if self._resolved_exception_handlers is Empty:
-            self._resolved_exception_handlers = {}
-            for layer in self.ownership_layers:
-                self._resolved_exception_handlers.update(layer.exception_handlers or {})
-        return cast("Dict[Union[int, Type[Exception]], ExceptionHandler]", self._resolved_exception_handlers)
+        resolved_exception_handlers = {}
+        for layer in self.ownership_layers:
+            resolved_exception_handlers.update(layer.exception_handlers or {})
+        return resolved_exception_handlers
 
     async def authorize_connection(self, connection: "HTTPConnection") -> None:
-        """
-        Ensures the connection is authorized by running all the route guards in scope
-        """
+        """Ensures the connection is authorized by running all the route guards
+        in scope."""
         for guard in self.resolve_guards():
             if is_async_callable(guard):
                 await guard(connection, copy(self))  # type: ignore[misc]
@@ -206,9 +188,8 @@ class BaseRouteHandler(Generic[T]):
 
     @staticmethod
     def _validate_dependency_is_unique(dependencies: Dict[str, Provide], key: str, provider: Provide) -> None:
-        """
-        Validates that a given provider has not been already defined under a different key
-        """
+        """Validates that a given provider has not been already defined under a
+        different key."""
         for dependency_key, value in dependencies.items():
             if provider == value:
                 raise ImproperlyConfiguredException(
@@ -217,8 +198,7 @@ class BaseRouteHandler(Generic[T]):
                 )
 
     def _validate_handler_function(self) -> None:
-        """
-        Validates the route handler function once set by inspecting its return annotations
-        """
+        """Validates the route handler function once set by inspecting its
+        return annotations."""
         if not self.fn:
             raise ImproperlyConfiguredException("Cannot call _validate_handler_function without first setting self.fn")
