@@ -1,6 +1,6 @@
-from .helpers import is_async_callable
 from .model import convert_dataclass_to_model, create_parsed_model_field
 from .module_loading import import_string
+from .predicates import is_async_callable, is_class_and_subclass
 from .sequence import find_index, unique
 from .url import join_paths, normalize_path
 
@@ -8,9 +8,10 @@ __all__ = [
     "convert_dataclass_to_model",
     "create_parsed_model_field",
     "find_index",
-    "join_paths",
     "import_string",
     "is_async_callable",
+    "is_class_and_subclass",
+    "join_paths",
     "normalize_path",
     "unique",
 ]
